@@ -28,6 +28,7 @@ The :func:`.main` function is the entry point of command line interface.
 
 from __future__ import division, unicode_literals
 
+import re
 import os
 import sys
 import argparse
@@ -38,16 +39,36 @@ from itertools import islice
 import multiprocessing as mp
 
 import pkg_resources
-from six import add_metaclass, iteritems, itervalues, text_type
+from six import add_metaclass, iteritems, itervalues, text_type, PY3
 
 from . import __version__ as package_version
 from .datasource import native, sbml
 from .datasource.context import FilePathContext
 from .lpsolver import generic
 
+import codecs
+
+if PY3:
+    unicode = str
+if not PY3:
+    if sys.stdout.encoding != 'UTF-8':
+        sys.stdout = codecs.getwriter('utf-8')(sys.stdout, 'strict')
+
 logger = logging.getLogger(__name__)
 
 
+def convert_to_unicode(str_, encoding='UTF-8'):
+    if PY3 or bool(re.search(r'\\u', str_)):
+        try:
+            return str_.encode('latin-1').decode('unicode-escape')
+        except:
+            return str_
+    else:
+        if isinstance(str_, unicode):
+            return str_
+        return str_.decode(encoding)
+
+
 class CommandError(Exception):
     """Error from running a command.
 
@@ -130,10 +151,10 @@ class ObjectiveMixin(object):
 
     Allows the user to override the default objective from the command line.
     """
-
     @classmethod
     def init_parser(cls, parser):
-        parser.add_argument('--objective', help='Reaction to use as objective')
+        parser.add_argument('--objective', type=convert_to_unicode,
+                            help='Reaction to use as objective')
         super(ObjectiveMixin, cls).init_parser(parser)
 
     def _get_objective(self, log=True):
@@ -218,7 +239,10 @@ class SolverCommandMixin(object):
     def init_parser(cls, parser):
         parser.add_argument(
             '--solver', action='append', type=str,
-            help='Specify solver requirements (e.g. "rational=yes")')
+            help='Specify solver requirements (e.g. "rational=yes")\n'
+                 'Choices: \trational, integer, quadratic, '
+                 'threads. feasibility_tolerance, optimality_tolerance, '
+                 'integrality_tolerance')
         super(SolverCommandMixin, cls).init_parser(parser)
 
     def __init__(self, *args, **kwargs):
@@ -284,7 +308,6 @@ class FilePrefixAppendAction(argparse.Action):
 
         self.__fromfile_prefix_chars = fromfile_prefix_chars
         self.__final_type = kwargs.get('type')
-        kwargs['type'] = text_type
 
         super(FilePrefixAppendAction, self).__init__(
             option_strings, dest, **kwargs)
@@ -294,7 +317,7 @@ class FilePrefixAppendAction(argparse.Action):
         if arguments is None or len(arguments) == 0:
             arguments = []
             setattr(namespace, self.dest, arguments)
-
+        values = text_type(values)
         if len(values) > 0 and values[0] in self.__fromfile_prefix_chars:
             filepath = values[1:]
             try:
